pub struct ReviewItem {
pub queue_id: i64,
pub face_id: i64,
pub candidate_cluster_id: i64,
pub candidate_cluster_name: Option<String>,
pub candidate_cluster_size: i64,
pub candidate_sample_face_ids: Vec<i64>,
pub score: f32,
}Expand description
A row from face_review_queue ready to be presented to the user.
Sample face ids are a small set of representative faces from the candidate cluster, used by the UI to show “here’s the person we think this matches.”
Fields
queue_id: i64face_id: i64candidate_cluster_id: i64candidate_cluster_name: Option<String>candidate_cluster_size: i64candidate_sample_face_ids: Vec<i64>score: f32Trait Implementations
Sourceimpl Clone for ReviewItem
impl Clone for ReviewItem
Sourcefn clone(&self) -> ReviewItem
fn clone(&self) -> ReviewItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ReviewItem
impl RefUnwindSafe for ReviewItem
impl Send for ReviewItem
impl Sync for ReviewItem
impl Unpin for ReviewItem
impl UnsafeUnpin for ReviewItem
impl UnwindSafe for ReviewItem