pub struct FaceDetector { /* private fields */ }Expand description
SCRFD Face Detector
Implementations
Sourceimpl FaceDetector
impl FaceDetector
Sourcepub fn new_with_threads<P: AsRef<Path>>(
runtime: &OnnxRuntime,
model_path: P,
intra_threads: usize,
) -> Result<Self>
pub fn new_with_threads<P: AsRef<Path>>( runtime: &OnnxRuntime, model_path: P, intra_threads: usize, ) -> Result<Self>
Load the SCRFD model with a specific thread count per session.
Sourcepub fn with_confidence_threshold(self, threshold: f32) -> Self
pub fn with_confidence_threshold(self, threshold: f32) -> Self
Set confidence threshold for detection
Sourcepub fn detect(&mut self, image: &DynamicImage) -> Vec<DetectedFace>
pub fn detect(&mut self, image: &DynamicImage) -> Vec<DetectedFace>
Detect faces in an image
Sourcepub fn detect_adaptive(&mut self, image: &DynamicImage) -> Vec<DetectedFace>
pub fn detect_adaptive(&mut self, image: &DynamicImage) -> Vec<DetectedFace>
Detect faces with adaptive multi-scale fallback for high-res images.
Pass 1: normal full-frame detection. Pass 2 (fallback): overlapping high-res tiles if pass 1 found no faces and image is large, to recover small/profile faces lost by global resizing.