pub struct LocalEmbedder { /* private fields */ }Expand description
Local ArcFace Face Embedder using ONNX Runtime.
Implementations
Sourceimpl LocalEmbedder
impl LocalEmbedder
Sourcepub fn new_with_threads<P: AsRef<Path>>(
runtime: &OnnxRuntime,
model_path: P,
intra_threads: usize,
) -> Result<Self>
pub fn new_with_threads<P: AsRef<Path>>( runtime: &OnnxRuntime, model_path: P, intra_threads: usize, ) -> Result<Self>
Load the ArcFace model with a specific thread count per session.
Sourcepub fn embed(&mut self, aligned_face: &RgbImage) -> Option<FaceEmbedding>
pub fn embed(&mut self, aligned_face: &RgbImage) -> Option<FaceEmbedding>
Generate embedding for an aligned face image (112x112)
Sourcepub fn embed_batch(&mut self, faces: &[RgbImage]) -> Vec<Option<FaceEmbedding>>
pub fn embed_batch(&mut self, faces: &[RgbImage]) -> Vec<Option<FaceEmbedding>>
Generate embeddings for a batch of aligned face images. Returns one Option per input; None if that input was invalid.